<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


declare(strict_types=1);

namespace MSSQLModule\Controller;


use App\itnovum\openITCOCKPIT\Wizard\CreateService;
use App\itnovum\openITCOCKPIT\Wizard\UpdateHost;
use App\Model\Entity\Host;
use App\Model\Table\HostsTable;
use App\Model\Table\HosttemplatesTable;
use App\Model\Table\ServicesTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use Cake\Http\Exception\NotFoundException;
use Cake\ORM\TableRegistry;
use Cake\Utility\Hash;
use MSSQLModule\Form\MSSqlForm;
use itnovum\openITCOCKPIT\Core\ValueObjects\User;

/**
 * Class WizardsController
 * @package MSSQLModule\Controller
 */
class WizardsController extends AppController {


    /**
     * @param null $hostId
     */
    public function mssql($hostId = null) {
        if (!$this->isApiRequest()) {
            //Only ship HTML template for angular
            return;
        }

        /** @var WizardAssignmentsTable $WizardAssignmentsTable */
        $WizardAssignmentsTable = TableRegistry::getTableLocator()->get('WizardAssignments');
        $wizards = $WizardAssignmentsTable->getAvailableWizards($this->PERMISSIONS);
        /** @var ServicesTable $ServicesTable */
        $ServicesTable = TableRegistry::getTableLocator()->get('Services');
        /** @var HostsTable $HostsTable */
        $HostsTable = TableRegistry::getTableLocator()->get('Hosts');

        if ($this->request->is('get') && $this->isAngularJsRequest()) {
            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }
            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }

            $hostCustomVariables = $HostsTable->get($hostId, [
                'contain' => [
                    'Customvariables'
                ]
            ])->getCustomvariablesForCfg();

            $dbuser = '';
            if (!empty($hostCustomVariables['_DBUSER'])) {
                $dbuser = $hostCustomVariables['_DBUSER'];
            }
            $dbpass = '';
            if (!empty($hostCustomVariables['_DBPASS'])) {
                $dbpass = $hostCustomVariables['_DBPASS'];
            }

            $this->set('dbuser', $dbuser);
            $this->set('dbpass', $dbpass);


            //Return mssql  wizard data
            $servicetemplates = [];
            $wizardAssignments = [];
            $msSqlData = $wizards['mssql'] ?? null;
            if ($msSqlData) {
                if ($WizardAssignmentsTable->existsByUuidAndTypeId($msSqlData['uuid'], $msSqlData['type_id'])) {
                    $wizardAssignments = Hash::merge($msSqlData, $WizardAssignmentsTable->getWizardByUuidForEdit($msSqlData['uuid']));
                }
            }
            if (!empty($wizardAssignments['servicetemplates']['_ids'])) {
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');
                $servicetemplates = $ServicetemplatesTable->getServicetemplatesFoWizardDeploy(
                    $wizardAssignments['servicetemplates']['_ids'],
                    $this->MY_RIGHTS
                );
            }
            $servicesNamesForExistCheck = $ServicesTable->getServiceNamesByHostIdForWizard($hostId);


            $this->set('servicetemplates', $servicetemplates);
            $this->set('servicesNamesForExistCheck', $servicesNamesForExistCheck);

            $this->viewBuilder()->setOption('serialize', [
                'servicetemplates',
                'servicesNamesForExistCheck',
                'dbuser',
                'dbpass'
            ]);
            return;
        }
        if ($this->request->is('post') && $this->isAngularJsRequest()) {
            $hostId = $this->request->getData('host_id', 0);

            if (!$HostsTable->existsById($hostId)) {
                throw new NotFoundException();
            }
            $host = $HostsTable->getHostByIdForPermissionCheck($hostId);
            if (!$this->allowedByContainerId($host->getContainerIds())) {
                $this->render403();
                return;
            }
            $MSSqlForm = new MSSqlForm();
            $data = $this->request->getData(null, []);
            $MSSqlForm->execute($data);

            if (!empty($MSSqlForm->getErrors())) {
                $this->response = $this->response->withStatus(400);
                $this->set('error', $MSSqlForm->getErrors());
                $this->viewBuilder()->setOption('serialize', ['error']);
                return;
            }

            //Wizard validation successfully - update host and create services
            $User = new User($this->getUser());

            /** @var HosttemplatesTable $HosttemplatesTable */
            $HosttemplatesTable = TableRegistry::getTableLocator()->get('Hosttemplates');

            // Get host and host template for merge
            $host = $HostsTable->getHostForEdit($hostId);
            $hosttemplate = $HosttemplatesTable->getHosttemplateForDiff($host['Host']['hosttemplate_id']);

            //Update custom variables
            $hostCustomVariablestoCheck = [
                'DBUSER' => 'dbuser',
                'DBPASS' => 'dbpass'
            ];

            //Update host with changelog
            $hostEntity = UpdateHost::save(
                $host,
                $hosttemplate,
                $data,
                $hostCustomVariablestoCheck,
                $HostsTable,
                $User
            );

            if ($hostEntity instanceof Host) {
                //Host updated successfully - create services
                /** @var ServicetemplatesTable $ServicetemplatesTable */
                $ServicetemplatesTable = TableRegistry::getTableLocator()->get('Servicetemplates');

                // Save default SAP services
                CreateService::saveMany(
                    $hostEntity,
                    $data['services'],
                    $data,
                    [],
                    $HostsTable,
                    $HosttemplatesTable,
                    $ServicesTable,
                    $ServicetemplatesTable,
                    $User
                );
            }
        }
        return;
    }
}
