<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


namespace MSSQLModule\Lib\InitialDatabase;

use App\Model\Table\CommandsTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package MSSQLModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {
    /**
     * @var CommandsTable
     */
    private $CommandsTable;

    /**
     * @var ServicetemplatesTable
     */
    private $ServicetemplatesTable;

    /**
     * @var WizardAssignmentsTable
     */
    private $WizardAssignmentsTable;

    /**
     * @var array
     */
    private $mapping = [];

    /**
     * TemplateImport constructor.
     * @param CommandsTable $CommandsTable
     * @param ServicetemplatesTable $ServicetemplatesTable
     * @param WizardAssignmentsTable $WizardAssignmentsTable
     */
    public function __construct(CommandsTable $CommandsTable, ServicetemplatesTable $ServicetemplatesTable, WizardAssignmentsTable $WizardAssignmentsTable) {
        $this->CommandsTable = $CommandsTable;
        $this->ServicetemplatesTable = $ServicetemplatesTable;
        $this->WizardAssignmentsTable = $WizardAssignmentsTable;
    }

    /**
     * @return bool
     */
    public function import() {
        $data = $this->getData();
        foreach ($data['Commands'] as $command) {
            if (isset($command['uuid']) && !$this->CommandsTable->existsByUuid($command['uuid'])) {
                $entity = $this->CommandsTable->newEntity($command);
                $this->CommandsTable->save($entity);
            }
        }
        $this->mapping['servicetemplates'] = [];

        foreach ($data['Servicetemplates'] as $servicetemplate) {
            if ($this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                $existingServicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplate['uuid']);
                $this->mapping['servicetemplates'][$servicetemplate['uuid']] = $existingServicetemplate['Servicetemplate']['id'];
                //skip current template if it already exists
                continue;
            }
            if (isset($servicetemplate['uuid']) && !$this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                if (isset($servicetemplate['command_id']) && $this->CommandsTable->existsByUuid($servicetemplate['command_id'])) {
                    $command = $this->CommandsTable->getCommandByUuid($servicetemplate['command_id'], true, false)[0];
                    $servicetemplate['command_id'] = $command['id'];
                    if (!empty($servicetemplate['servicetemplatecommandargumentvalues']) && !empty($command['commandarguments'])) {
                        foreach ($servicetemplate['servicetemplatecommandargumentvalues'] as $templateArgumentKey => $templateArgumentValue) {
                            $servicetemplate['servicetemplatecommandargumentvalues'][$templateArgumentKey] = [
                                'commandargument_id' => $this->getCommandArgumentIdByName($templateArgumentValue['commandargument_id'], $command['commandarguments']),
                                'value'              => $templateArgumentValue['value'],
                            ];
                        }
                    }
                    $entity = $this->ServicetemplatesTable->newEntity($servicetemplate);
                    $this->ServicetemplatesTable->save($entity);
                    $this->mapping['servicetemplates'][$entity->get('uuid')] = $entity->get('id');
                }
            }
        }

        if (!empty($data['Wizardassignment'])) {
            $wizardassignmentEntity['uuid'] = $data['Wizardassignment']['uuid'];
            $wizardassignmentEntity['type_id'] = $data['Wizardassignment']['type_id'];
            foreach ($data['Wizardassignment']['servicetemplates']['_ids'] as $servicetemplateUuid) {
                $servicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplateUuid);
                if (isset($servicetemplate['Servicetemplate']) && isset($servicetemplate['Servicetemplate']['id'])) {
                    $wizardassignmentEntity['servicetemplates']['_ids'][] = $servicetemplate['Servicetemplate']['id'];
                }
            }
            if (!$this->WizardAssignmentsTable->existsByUuidAndTypeId($wizardassignmentEntity['uuid'], $wizardassignmentEntity['type_id'])) {
                $entity = $this->WizardAssignmentsTable->newEntity($wizardassignmentEntity);
                $this->WizardAssignmentsTable->save($entity);
            } else {
                $existingAssignment = $this->WizardAssignmentsTable->getWizardByUuidForEdit($wizardassignmentEntity['uuid']);
                foreach (array_diff($wizardassignmentEntity['servicetemplates']['_ids'], $existingAssignment['servicetemplates']['_ids']) as $missingServicetemplateId) {
                    $existingAssignment['servicetemplates']['_ids'][] = $missingServicetemplateId;
                }
                $entity = $this->WizardAssignmentsTable->get($existingAssignment['id']);
                $entity = $this->WizardAssignmentsTable->patchEntity($entity, $existingAssignment);
                $this->WizardAssignmentsTable->save($entity);
            }
        }
        return true;
    }

    /**
     * @return array
     */
    public function getData() {
        return [
            'Commands'         => $this->getCommandsData(),
            'Servicetemplates' => $this->getServicetemplatesData(),
            'Wizardassignment' => $this->getWizardAssignmentData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 => [
                'name'             => 'check_mssql_health_name',
                'command_line'     => '$USER1$/check_mssql_health --server=$ARG1$ --username="$_HOSTDBUSER$" --password="$_HOSTDBPASS$" --mode=$ARG2$ --currentdb=$ARG3$ --warning=$ARG4$ --critical=$ARG5$ --commit',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => 'ad1d18aa-d5d8-45e6-94ce-f95e2124815d',
                'description'      => '',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Instance',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Mode',
                    ],
                    2 => [
                        'name'       => '$ARG3$',
                        'human_name' => 'Database',
                    ],
                    3 => [
                        'name'       => '$ARG4$',
                        'human_name' => 'Warning',
                    ],
                    4 => [
                        'name'       => '$ARG5$',
                        'human_name' => 'Critical',
                    ],
                ],
            ],
            1 => [
                'name'             => 'check_mssql_health',
                'command_line'     => '$USER1$/check_mssql_health --server=$ARG1$ --username="$_HOSTDBUSER$" --password="$_HOSTDBPASS$" --mode=$ARG2$ --warning=$ARG3$ --critical=$ARG4$ --notemp --commit',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'description'      => '',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Instance',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Mode',
                    ],
                    2 => [
                        'name'       => '$ARG3$',
                        'human_name' => 'Warning',
                    ],
                    3 => [
                        'name'       => '$ARG4$',
                        'human_name' => 'Critical',
                    ],
                ],
            ],
            2 => [
                'name'             => 'check_mssql_health_currentdb',
                'command_line'     => '$USER1$/check_mssql_health --server=$ARG1$ --username="$_HOSTDBUSER$" --password="$_HOSTDBPASS$" --mode=$ARG2$ --currentdb=$ARG3$ --warning=$ARG4$ --critical=$ARG5$ --commit',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '37abddbb-1b36-4dd5-8c22-63dfcf19f146',
                'description'      => '',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Instance',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Mode',
                    ],
                    2 =>
                        [
                            'name'       => '$ARG3$',
                            'human_name' => 'Database',
                        ],
                    3 => [
                        'name'       => '$ARG4$',
                        'human_name' => 'Warning',
                    ],
                    4 => [
                        'name'       => '$ARG5$',
                        'human_name' => 'Critical',
                    ]
                ]
            ]
        ];
        return $data;
    }


    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0  => [
                'uuid'                                      => 'b9924399-8173-46ee-aca0-6d1f8422fcb6',
                'template_name'                             => 'MSSQL_CONNECTION-TIME',
                'name'                                      => 'Connection-Time DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '37abddbb-1b36-4dd5-8c22-63dfcf19f146',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'connection-time',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => 'DBNAME',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '2',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => '5',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            1  => [
                'uuid'                                      => '68e3d94e-276e-447e-89af-54287ac5502a',
                'template_name'                             => 'MSSQL_DATABASE_FREE',
                'name'                                      => 'Database-free DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => 'ad1d18aa-d5d8-45e6-94ce-f95e2124815d',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'database-free',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => 'DBNAME',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '10:',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => '5:',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            2  => [
                'uuid'                                      => '100f0167-cf7a-4f17-b9f1-d2d863fe46af',
                'template_name'                             => 'MSSQL_DATABASE_BACKUP_AGE',
                'name'                                      => 'Backup-Age INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'database-backup-age',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '24',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '48',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            3  => [
                'uuid'                                      => 'd2b13b43-ec4f-4691-8b87-eff49163b6fa',
                'template_name'                             => 'MSSQL_DATABASE_LOG_BACKUP_AGE',
                'name'                                      => 'Log-Backup-Age INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'database-logbackup-age',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '24',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '48',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            4  => [
                'uuid'                                      => '063f31c6-3fa2-4404-99d7-850d2f62a332',
                'template_name'                             => 'MSSQL_CPU_BUSY',
                'name'                                      => 'CPU Busy INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'cpu-busy',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '80',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '90',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            5  => [
                'uuid'                                      => '21b68fe2-ebb9-4110-9a00-933a9370ef69',
                'template_name'                             => 'MSSQL_IO_BUSY',
                'name'                                      => 'IO Busy INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'io-busy',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '80',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '90',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            6  => [
                'uuid'                                      => '48966d17-7636-4079-b1ec-b0e30e979809',
                'template_name'                             => 'MSSQL_FULL_SCANS',
                'name'                                      => 'Full Scans INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'full-scans',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '100',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '500',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            7  => [
                'uuid'                                      => 'c903a9aa-b642-4422-afd8-6320056117df',
                'template_name'                             => 'MSSQL_CONNECTED_USERS',
                'name'                                      => 'Connected Users INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'connected-users',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '100',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '150',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            8  => [
                'uuid'                                      => '814a7564-c12e-4829-a42a-d4915ca8c077',
                'template_name'                             => 'MSSQL_TRANSACTIONS',
                'name'                                      => 'Transactions DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => 'ad1d18aa-d5d8-45e6-94ce-f95e2124815d',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'transactions',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => 'DBNAME',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '10000',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => '50000',
                    ],
                ],
                'customvariables'                           =>
                    [
                    ],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            9  => [
                'uuid'                                      => '5cf5c4e1-082e-4346-984e-25ae1e5246e1',
                'template_name'                             => 'MSSQL_LOCKS_WAITS',
                'name'                                      => 'Locks waits INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'locks-waits',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '100',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '500',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            10 => [
                'uuid'                                      => '3293668d-dccf-4be7-8d21-49eb4672458a',
                'template_name'                             => 'MSSQL_LOCKS_DEADLOCKS',
                'name'                                      => 'Deadlocks INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'locks-deadlocks',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '1',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '5',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            11 => [
                'uuid'                                      => 'ff49c3a4-3755-4162-ad03-1aa3aad3a556',
                'template_name'                             => 'MSSQL_FAILED_JOBS',
                'name'                                      => 'Failed Jobs INSTANCENAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '335cf32e-a4b6-4b9b-8aab-00f95130a577',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '120',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-08 13:09:58',
                'modified'                                  => '2021-06-08 13:09:58',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => '$HOSTADDRESS$',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'failed-jobs',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '1',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '2',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
        ];
        return $data;
    }


    /**
     * @param string $name
     * @param array $commandarguments
     * @return bool|mixed
     */
    public function getCommandArgumentIdByName(string $name, array $commandarguments) {
        foreach ($commandarguments as $commandargument) {
            if (isset($commandargument['name']) && $commandargument['name'] === $name) {
                return $commandargument['id'];
            }
        }
        return false;
    }

    /**
     * @return array
     */
    public function getWizardAssignmentData() {
        $data = [

            'uuid'             => '39f75038-a6c7-4bed-8e6f-e5389e974336',
            'type_id'          => 'mssql',
            'servicetemplates' => [
                '_ids' => [
                    'b9924399-8173-46ee-aca0-6d1f8422fcb6',
                    '68e3d94e-276e-447e-89af-54287ac5502a',
                    '100f0167-cf7a-4f17-b9f1-d2d863fe46af',
                    'd2b13b43-ec4f-4691-8b87-eff49163b6fa',
                    '063f31c6-3fa2-4404-99d7-850d2f62a332',
                    '21b68fe2-ebb9-4110-9a00-933a9370ef69',
                    '48966d17-7636-4079-b1ec-b0e30e979809',
                    'c903a9aa-b642-4422-afd8-6320056117df',
                    '814a7564-c12e-4829-a42a-d4915ca8c077',
                    '5cf5c4e1-082e-4346-984e-25ae1e5246e1',
                    '3293668d-dccf-4be7-8d21-49eb4672458a',
                    'ff49c3a4-3755-4162-ad03-1aa3aad3a556'
                ]
            ]
        ];
        return $data;
    }
}
